`ensembleSize` <-
function (x) 
UseMethod("ensembleSize")

